==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/he.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "פרטיות",
    "-" : "-",
    "Add external admin" : "הוספת הנהלה חיצונית",
    "This server is using full-disk-encryption." : "השרת הזה משתמש בהצפנה על כל הכונן.",
    "Your files are not protected by encryption." : "הקבצים שלך אינם מוגנים בהצפנה.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}.",
    "This server is protected with full-disk-encryption." : "שרת זה מוגן בהצפנה על כל הכונן.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}. בנוסף, השרת הזה מוגן עם הצפנה על כל הכונן.",
    "Your data is located in: " : "הנתונים שלך נמצאים תחת:",
    "The admin hasn't selected the location of the server yet." : "המנהל לא בחר את מיקום השרת עדיין.",
    "You don't have any shares with individual users." : "אין לך שיתופים עם משתמשים בודדים.",
    "Somaliland" : "סומלילנד",
    "Andorra" : "אנדורה",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Antigua and Barbuda" : "אנטיגואה וברבודה",
    "Anguilla" : "אנגווילה",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Antarctica" : "אנטארקטיקה",
    "Argentina" : "ארגנטינה",
    "American Samoa" : "סמואה האמריקנית",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Aruba" : "ארובה",
    "Åland Islands" : "איי אולנד",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegovina" : "בוסניה והרצגובינה",
    "Barbados" : "ברבדוס",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Bahrain" : "בחריין",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Saint Barthélemy" : "סן ברתלמי",
    "Bermuda" : "ברמודה",
    "Brunei" : "ברוניי",
    "Bolivia" : "בוליביה",
    "Bonaire, Sint Eustatius and Saba" : "בונייר, סנט אוסטתיוס וסאבא",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Bouvet Island" : "האי בּוּבֶה",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Cocos (Keeling) Islands" : "איי קוקוס קילינג",
    "Democratic Republic of the Congo" : "הרפובליקה הדמוקרטית של קונגו",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Cote d'Ivoire" : "חוף השנהב",
    "Cook Islands" : "איי קוק",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cabo Verde" : "כף ורדה",
    "Curaçao" : "קוראסאו",
    "Christmas Island" : "אי חג המולד",
    "Cyprus" : "קפריסין",
    "Czech" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "West Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands" : "איי פוקלנד",
    "Faroe Islands" : "איי פארו",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom" : "הממלכה המאוחדת",
    "Grenada" : "גרנדה",
    "Georgia" : "גאורגיה",
    "French Guiana" : "גיאנה הצרפתית",
    "Guernsey" : "גרנזי",
    "Ghana" : "גאנה",
    "Gibraltar" : "גיברלטר",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Guadeloupe" : "גוואדלופ",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "Guatemala" : "גואטמלה",
    "Guam" : "גואם",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Honduras" : "הונדורס",
    "Hong Kong" : "הונג קונג",
    "Heard Island and McDonald Islands" : "האי הרד ואיי מקדונלד",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "Isle of Man" : "האי מאן",
    "India" : "הודו",
    "British Indian Ocean Territory" : "הטריטוריה הבריטית באוקיינוס ההודי",
    "Iraq" : "עיראק",
    "Iran" : "איראן",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "Kiribati" : "קיריבטי",
    "North Korea" : "קוריאה הצפונית",
    "South Korea" : "קוריאה הדרומית",
    "Kuwait" : "כווית",
    "Cayman Islands" : "איי קיימן",
    "Kazakhstan" : "קזחסטן",
    "Laos" : "לאוס",
    "Lebanon" : "לבנון",
    "Liechtenstein" : "ליכטנשטיין",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Monaco" : "מונקו",
    "Moldova" : "מולדובה",
    "Montenegro" : "מונטנגרו",
    "Madagascar" : "מדגסקר",
    "Marshall Islands" : "איי מרשל",
    "Macedonia" : "מקדוניה",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Macao" : "מקאו",
    "Northern Mariana Islands" : "איי מריאנה הצפוניים",
    "Mauritania" : "מאוריטניה",
    "Montserrat" : "מונטסראט",
    "Malta" : "מלטא",
    "Mauritius" : "מאוריציוס",
    "Maldives" : "האיים המלדיביים",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Norfolk Island" : "האי נורפוק",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "Nauru" : "נאורו",
    "Niue" : "ניואה",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "French Polynesia" : "פולינזיה הצרפתית",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Pitcairn" : "פיטקרן",
    "Puerto Rico" : "פוארטו ריקו",
    "Portugal" : "פורטוגל",
    "Palau" : "פלאו",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Réunion" : "ראוניון",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russia" : "רוסיה",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Slovenia" : "סלובניה",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "El Salvador" : "אל סלוודור",
    "Syria" : "סוריה",
    "Swaziland" : "אסוואטיני",
    "Chad" : "צ׳אד",
    "Fr. S. Antarctic Lands" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Taiwan" : "טאיוואן",
    "Tanzania" : "טנזניה",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Holy See" : "הכס הקדוש",
    "Venezuela" : "ונצואלה",
    "Vietnam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Samoa" : "סמואה",
    "Yemen" : "תימן",
    "Mayotte" : "מָיוֹט",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Your Nextcloud account" : "חשבון ה־Nextcloud שלך",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "הנתונים שלך מייצגים את מי שאתה וניתן לנצל אותם לרעה בקלות. אנחנו ב־Nextcloud מאמינים שיש לך את הזכות לבחור מה קורה לנתונים שלך. הזכויות שלך מוגנות עם Nextcloud כפי שמופיע בהצהרת נתוני המשתמשים!",
    "User Data Manifesto 2.0" : "הצהרת נתוני המשתמשים 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "הגדרת זכויות בסיסיות לשליטתם של האנשים בנתונים שלהם עצמם בעידן האינטרנט",
    "Control" : "שליטה",
    "over user data access" : "בגישה לנתוני משתמשים",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "הנתונים שנשלחים בצורה רצונית ומפורשת על ידי המשתמש אמורים להיות תחת שליטת המשתמש. למשתמשים אמורה להיות היכולת להחליט למי להעניק גישה ישירה לנתונים שלהם ותחת אילו הרשאות ורישיונות יש לאפשר את הגישה הזאת.",
    "Knowledge" : "ידע",
    "of how the data is stored" : "על אופן אחסון הנתונים",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "כאשר הנתונים נשלחים לספק שירות מסוים, יש ליידע את המשתמשים בנוגע למיקום בו ספק השירות מאחסן את הנתונים, למשך כמה זמן, תחת איזו סמכות מקומית ספק השירות פועל ואילו חוקים חלים.",
    "Freedom" : "חופש",
    "to choose a platform" : "לבחור פלטפורמה",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "המשתמשים יכולים לחלץ את הנתונים שלהם מהשירות בכל עת ללא אף נעילת ספק. כדי להבטיח זאת נדרש יישום מובנה של סוגי קבצים ופרוטוקולים שהכרחיים לתהליך.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Where is your data?" : "איפה הנתונים שלך?",
    "Who has access to your data?" : "למי יש גישה לנתונים שלך?",
    "Administrators" : "מנהלים",
    "People you shared with" : "אנשים אתם שיתפת",
    "Privacy policy" : "מדיניות פרטיות",
    "Read the privacy policy." : "הצגת מדיניות הפרטיות.",
    "Encryption" : "הצפנה",
    "Please select a country" : "נא לבחור מדינה",
    "Bosnia and Herzegowina" : "בוסניה והרצגובינה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/he.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "פרטיות",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "מרכז הפרטיות מציג היכן מאוחסנים הנתונים שלך ולמי יש אפשרות לגשת אליהם או בגלל ששיתפת אותם או בגלל שהם מנהלים.",
    "Remove external admin" : "הסרת הנהלה חיצונית",
    "Add external admin" : "הוספת הנהלה חיצונית",
    "Name of external admin" : "שם ההנהלה החיצונית",
    "This server is using full-disk-encryption." : "השרת הזה משתמש בהצפנה על כל הכונן.",
    "Your files are not protected by encryption." : "הקבצים שלך אינם מוגנים בהצפנה.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}.",
    "This server is protected with full-disk-encryption." : "שרת זה מוגן בהצפנה על כל הכונן.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}. בנוסף, השרת הזה מוגן עם הצפנה על כל הכונן.",
    "Your data is located in: " : "הנתונים שלך נמצאים תחת:",
    "The admin hasn't selected the location of the server yet." : "המנהל לא בחר את מיקום השרת עדיין.",
    "Change data location" : "החלפת מיקום הנתונים",
    "Please select a region" : "נא לבחור אזור",
    "You don't have any shares with individual users." : "אין לך שיתופים עם משתמשים בודדים.",
    "Somaliland" : "סומלילנד",
    "Andorra" : "אנדורה",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Antigua and Barbuda" : "אנטיגואה וברבודה",
    "Anguilla" : "אנגווילה",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Antarctica" : "אנטארקטיקה",
    "Argentina" : "ארגנטינה",
    "American Samoa" : "סמואה האמריקנית",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Aruba" : "ארובה",
    "Åland Islands" : "איי אולנד",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegovina" : "בוסניה והרצגובינה",
    "Barbados" : "ברבדוס",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Bahrain" : "בחריין",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Saint Barthélemy" : "סן ברתלמי",
    "Bermuda" : "ברמודה",
    "Brunei" : "ברוניי",
    "Bolivia" : "בוליביה",
    "Bonaire, Sint Eustatius and Saba" : "בונייר, סנט אוסטתיוס וסאבא",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Bouvet Island" : "האי בּוּבֶה",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Cocos (Keeling) Islands" : "איי קוקוס קילינג",
    "Democratic Republic of the Congo" : "הרפובליקה הדמוקרטית של קונגו",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Cote d'Ivoire" : "חוף השנהב",
    "Cook Islands" : "איי קוק",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cabo Verde" : "כף ורדה",
    "Curaçao" : "קוראסאו",
    "Christmas Island" : "אי חג המולד",
    "Cyprus" : "קפריסין",
    "Czech" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "West Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands" : "איי פוקלנד",
    "Micronesia" : "מיקרונזיה",
    "Faroe Islands" : "איי פארו",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom" : "הממלכה המאוחדת",
    "Grenada" : "גרנדה",
    "Georgia" : "גאורגיה",
    "French Guiana" : "גיאנה הצרפתית",
    "Guernsey" : "גרנזי",
    "Ghana" : "גאנה",
    "Gibraltar" : "גיברלטר",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Guadeloupe" : "גוואדלופ",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "South Georgia and the South Sandwich Islands" : "איי ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים",
    "Guatemala" : "גואטמלה",
    "Guam" : "גואם",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Honduras" : "הונדורס",
    "Hong Kong" : "הונג קונג",
    "Heard Island and McDonald Islands" : "האי הרד ואיי מקדונלד",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "Isle of Man" : "האי מאן",
    "India" : "הודו",
    "British Indian Ocean Territory" : "הטריטוריה הבריטית באוקיינוס ההודי",
    "Iraq" : "עיראק",
    "Iran" : "איראן",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "Kiribati" : "קיריבטי",
    "Comores" : "קומורו",
    "Saint Kitts and Nevis" : "סנט קיטס ונוויס",
    "North Korea" : "קוריאה הצפונית",
    "South Korea" : "קוריאה הדרומית",
    "Kuwait" : "כווית",
    "Cayman Islands" : "איי קיימן",
    "Kazakhstan" : "קזחסטן",
    "Laos" : "לאוס",
    "Lebanon" : "לבנון",
    "Saint Lucia" : "סנט לוסיה",
    "Liechtenstein" : "ליכטנשטיין",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Monaco" : "מונקו",
    "Moldova" : "מולדובה",
    "Montenegro" : "מונטנגרו",
    "Saint Martin" : "סן מרטן",
    "Madagascar" : "מדגסקר",
    "Marshall Islands" : "איי מרשל",
    "Macedonia" : "מקדוניה",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Macao" : "מקאו",
    "Northern Mariana Islands" : "איי מריאנה הצפוניים",
    "Mauritania" : "מאוריטניה",
    "Montserrat" : "מונטסראט",
    "Malta" : "מלטא",
    "Mauritius" : "מאוריציוס",
    "Maldives" : "האיים המלדיביים",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Norfolk Island" : "האי נורפוק",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "Nauru" : "נאורו",
    "Niue" : "ניואה",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "French Polynesia" : "פולינזיה הצרפתית",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Saint Pierre and Miquelon" : "סן-פייר ומיקלון",
    "Pitcairn" : "פיטקרן",
    "Puerto Rico" : "פוארטו ריקו",
    "Palestine" : "הרשות הפלשתינית",
    "Portugal" : "פורטוגל",
    "Palau" : "פלאו",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Réunion" : "ראוניון",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russia" : "רוסיה",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Seychelles" : "איי סיישל",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Saint Helena, Ascension and Tristan da Cunha" : "סנט הלנה, אסנשן וטריסטן דה קונה",
    "Slovenia" : "סלובניה",
    "Svalbard and Jan Mayen" : "סבאלברד ויאן מאיין",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "San Marino" : "סן מרינו",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "Sao Tome and Principe" : "סאו טומה ופרינסיפה",
    "El Salvador" : "אל סלוודור",
    "Sint Maarten" : "סנט מארטן",
    "Syria" : "סוריה",
    "Swaziland" : "אסוואטיני",
    "Turks and Caicos Islands" : "איי טרקס וקייקוס",
    "Chad" : "צ׳אד",
    "Fr. S. Antarctic Lands" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Tokelau" : "טוקלאו",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Tonga" : "טונגאית",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Tuvalu" : "טובאלו",
    "Taiwan" : "טאיוואן",
    "Tanzania" : "טנזניה",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States Minor Outlying Islands" : "האיים המרוחקים הקטנים של ארה״ב",
    "United States" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Holy See" : "הכס הקדוש",
    "Saint Vincent and the Grenadines" : "סנט וינסנט והגרנדינים",
    "Venezuela" : "ונצואלה",
    "Virgin Islands (British)" : "איי הבתולה (הבריטיים)",
    "Virgin Islands (U.S.)" : "איי הבתולה (ארה״ב)",
    "Vietnam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Wallis and Futuna" : "ואליס ופוטונה",
    "Samoa" : "סמואה",
    "Yemen" : "תימן",
    "Mayotte" : "מָיוֹט",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Your Nextcloud account" : "חשבון ה־Nextcloud שלך",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "הנתונים שלך מייצגים את מי שאתה וניתן לנצל אותם לרעה בקלות. אנחנו ב־Nextcloud מאמינים שיש לך את הזכות לבחור מה קורה לנתונים שלך. הזכויות שלך מוגנות עם Nextcloud כפי שמופיע בהצהרת נתוני המשתמשים!",
    "User Data Manifesto 2.0" : "הצהרת נתוני המשתמשים 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "הגדרת זכויות בסיסיות לשליטתם של האנשים בנתונים שלהם עצמם בעידן האינטרנט",
    "Control" : "שליטה",
    "over user data access" : "בגישה לנתוני משתמשים",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "הנתונים שנשלחים בצורה רצונית ומפורשת על ידי המשתמש אמורים להיות תחת שליטת המשתמש. למשתמשים אמורה להיות היכולת להחליט למי להעניק גישה ישירה לנתונים שלהם ותחת אילו הרשאות ורישיונות יש לאפשר את הגישה הזאת.",
    "Knowledge" : "ידע",
    "of how the data is stored" : "על אופן אחסון הנתונים",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "כאשר הנתונים נשלחים לספק שירות מסוים, יש ליידע את המשתמשים בנוגע למיקום בו ספק השירות מאחסן את הנתונים, למשך כמה זמן, תחת איזו סמכות מקומית ספק השירות פועל ואילו חוקים חלים.",
    "Freedom" : "חופש",
    "to choose a platform" : "לבחור פלטפורמה",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "המשתמשים יכולים לחלץ את הנתונים שלהם מהשירות בכל עת ללא אף נעילת ספק. כדי להבטיח זאת נדרש יישום מובנה של סוגי קבצים ופרוטוקולים שהכרחיים לתהליך.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Where is your data?" : "איפה הנתונים שלך?",
    "Who has access to your data?" : "למי יש גישה לנתונים שלך?",
    "Administrators" : "מנהלים",
    "People you shared with" : "אנשים אתם שיתפת",
    "Privacy policy" : "מדיניות פרטיות",
    "Read the privacy policy." : "הצגת מדיניות הפרטיות.",
    "Encryption" : "הצפנה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
